summaryrefslogtreecommitdiffstats
path: root/kdecore/kstdaccel.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdecore/kstdaccel.h')
-rw-r--r--kdecore/kstdaccel.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kdecore/kstdaccel.h b/kdecore/kstdaccel.h
index 008f71227..9f379b210 100644
--- a/kdecore/kstdaccel.h
+++ b/kdecore/kstdaccel.h
@@ -237,25 +237,25 @@ namespace KStdAccel
* Find, search. Default: Ctrl-f
* @return the shortcut of the standard accelerator
*/
- KDECORE_EXPORT const KShortcut& tqfind();
+ KDECORE_EXPORT const KShortcut& find();
/**
* Find/search next. Default: F3
* @return the shortcut of the standard accelerator
*/
- KDECORE_EXPORT const KShortcut& tqfindNext();
+ KDECORE_EXPORT const KShortcut& findNext();
/**
* Find/search previous. Default: Shift-F3
* @return the shortcut of the standard accelerator
*/
- KDECORE_EXPORT const KShortcut& tqfindPrev();
+ KDECORE_EXPORT const KShortcut& findPrev();
/**
* Find and tqreplace matches. Default: Ctrl-r
* @return the shortcut of the standard accelerator
*/
- KDECORE_EXPORT const KShortcut& tqreplace();
+ KDECORE_EXPORT const KShortcut& replace();
/**
* Zoom in. Default: Ctrl-Plus
@@ -237,25 +237,25 @@ namespace KStdAccel
/**
- * Find and tqreplace matches. Default: Ctrl-r
+ * Find and replace matches. Default: Ctrl-r
* @return the shortcut of the standard accelerator
*/